@@ -1,9 +1,9 @@
 ## Compute the entropy of a distribution
 
-entropy <- function(distrib)
+entropy <- function(distrib, base=exp(1))
 	{
 		distrib <- distrib[distrib!=0]
 		p <- distrib/sum(distrib)
-		e <- -sum(p*log(p))
+		e <- -sum(p*log(p, base=base))
 		return(e)
 	}
